#!/bin/bash
set -u

# Entry file for running plain Docker containers
# Runs the tests saves output in shared folder
# Note that the output file is collected by script run_docker_tests.sh
# This is executed as 'root'.

declare SDPTestOutputDir="/sdp/test/output"
declare Cmd=
declare Log="$SDPTestOutputDir/test-${TESTOS}.out"

function msg () { echo -e "$*"; }
function bail () { msg "\\nError: ${1:-Unknown Error}\\n"; exit "${2:-1}"; }

msg TESTOS=${TESTOS:-Unset}

[[ "$TESTOS" == "Unset" ]] &&
   bail "Required environment var TESTOS not set. Should be 'centos7' or simmilar\\nvalue. Aborting.\\n"

if [[ ! -d "$SDPTestOutputDir" ]]; then
   Cmd="sudo mkdir -p $SDPTestOutputDir"
   msg "Running: $Cmd"
   $Cmd || bail "Failed to create dir: $SDPTestOutputDir"
fi

Cmd="sudo chown -R perforce:perforce ${SDPTestOutputDir%/*}"
msg "Running: $Cmd"
$Cmd || bail "Failed: chown -R perforce:perforce /sdp/test"

Cmd="su -l perforce -c /p4/test_sdp.sh"
msg "Running: $Cmd\\nLogging to: $Log"

$Cmd > "$Log" 2>&1
